@@ -890,12 +890,16 @@ impl Converter {
             }
 
             if li_finished {
-                let contents = self
-                    .block_process(li_lines.clone())
-                    // if it errors then fail fairly gracefully
-                    .unwrap_or_default();
+                if li_lines.len() == 1 {
+                    li_array.push(NodeData { tag: "li".to_string(), text: Some(li_lines[0].clone()), misc: li_number.clone(), contents: vec![] });
+                } else {
+                    let contents = self
+                        .block_process(li_lines.clone())
+                        // if it errors then fail fairly gracefully
+                        .unwrap_or_default();
 
-                li_array.push(NodeData { tag: "li".to_string(), text: None, misc: li_number.clone(), contents });
+                    li_array.push(NodeData { tag: "li".to_string(), text: None, misc: li_number.clone(), contents });
+                }
 
                 // reset for next round
                 li_finished = false;
@@ -1494,6 +1498,8 @@ impl Converter {
 
                     let processed = if !node.contents.is_empty() {
                         self.block_merge(node.contents, depth+1)
+                    } else if let Some(text) = node.text{
+                        text
                     } else {
                         "".to_string()
                     };
@@ -2525,3 +2531,4 @@ impl Converter {
         result.join("\n")
     }
 }
+//
